@@ -35,6 +35,7 @@ from sphinx.testing.util import SphinxTestApp
 from sphobjinv import Inventory
 
 from sphinx_autodoc_typehints import (
+    _resolve_type_guarded_imports,
     backfill_type_hints,
     format_annotation,
     get_annotation_args,
@@ -221,14 +222,14 @@ def test_format_annotation(inv: Inventory, annotation: Any, expected_result: str
         # Test with the "fully_qualified" flag turned on
         if "typing" in expected_result_not_simplified:
             expected_result_not_simplified = expected_result_not_simplified.replace("~typing", "typing")
-            conf = create_autospec(Config, fully_qualified=True, simplify_optional_unions=False)
+            conf = create_autospec(Config, typehints_fully_qualified=True, simplify_optional_unions=False)
             assert format_annotation(annotation, conf) == expected_result_not_simplified
 
     # Test with the "fully_qualified" flag turned on
     if "typing" in expected_result or __name__ in expected_result:
         expected_result = expected_result.replace("~typing", "typing")
         expected_result = expected_result.replace("~" + __name__, __name__)
-        conf = create_autospec(Config, fully_qualified=True)
+        conf = create_autospec(Config, typehints_fully_qualified=True)
         assert format_annotation(annotation, conf) == expected_result
 
     # Test for the correct role (class vs data) using the official Sphinx inventory
@@ -822,4 +823,12 @@ def test_resolve_typing_guard_imports(app: SphinxTestApp, status: StringIO, warn
     set_python_path()
     app.build()
     assert "build succeeded" in status.getvalue()
-    assert not warning.getvalue()
+    pat = r'WARNING: Failed guarded type import with ImportError\("cannot import name \'missing\' from \'functools\''
+    err = warning.getvalue()
+    assert re.search(pat, err)
+
+
+def test_no_source_code_type_guard() -> None:
+    from csv import Error
+
+    _resolve_type_guarded_imports(Error)
